@@ -35,6 +35,7 @@ using SemWeb;
 
 namespace Beagle.Filters {
 	
+	[PropertyKeywordMapping (Keyword="imagemodel",     PropertyName="exif:Model",    IsKeyword=true)]
 	public class FilterJpeg : FilterImage {
 
 		public FilterJpeg () : base ()
@@ -49,9 +50,11 @@ namespace Beagle.Filters {
 			byte [] commentdata = header.GetJFIFComment();
 			if (commentdata != null && commentdata.Length != 0)
 			{
-				string comment = System.Text.Encoding.ASCII.GetString( commentdata, 0, commentdata.Length );
-				if (comment != null && comment != "")
+				string comment = System.Text.Encoding.Default.GetString( commentdata, 0, commentdata.Length );
+				if (comment != null && comment != "") {
 					AddProperty (Beagle.Property.New ("jfif:Comment", comment));
+					AddProperty (Beagle.Property.NewUnstored ("fixme:comment", comment));
+				}
 			}
 
 			byte [] data = header.GetRawExif ();
@@ -64,52 +67,57 @@ namespace Beagle.Filters {
 			string str;
 			
 			str = exif.LookupFirstValue (ExifTag.UserComment);
-			if (str != null && str != "")
+			if (str != null && str != "") {
 				AddProperty (Beagle.Property.New ("exif:UserComment", str));
+				AddProperty (Beagle.Property.NewUnstored ("fixme:comment", str));
+			}
+
 
 			str = exif.LookupFirstValue (ExifTag.ImageDescription);
-			if (str != null && str != "")
+			if (str != null && str != "") {
 				AddProperty (Beagle.Property.New ("exif:ImageDescription", str));
+				AddProperty (Beagle.Property.NewUnstored ("fixme:comment", str));
+			}
 
 			str = exif.LookupFirstValue (ExifTag.PixelXDimension);
 			if (str != null && str != "") {
 				Width = Int32.Parse (str);
-				AddProperty (Beagle.Property.NewKeyword ("exif:PixelXDimension", str));
+				AddProperty (Beagle.Property.NewUnsearched ("exif:PixelXDimension", str));
 			}
 
 			str = exif.LookupFirstValue (ExifTag.PixelYDimension);
 			if (str != null && str != "") {
 				Height = Int32.Parse (str);
-				AddProperty (Beagle.Property.NewKeyword ("exif:PixelYDimension", str));
+				AddProperty (Beagle.Property.NewUnsearched ("exif:PixelYDimension", str));
 			}
 
 			str = exif.LookupFirstValue (ExifTag.ISOSpeedRatings);
 			if (str != null && str != "")
-				AddProperty (Beagle.Property.NewKeyword ("exif:ISOSpeedRatings", str));
+				AddProperty (Beagle.Property.NewUnsearched ("exif:ISOSpeedRatings", str));
 
 			str = exif.LookupFirstValue (ExifTag.ShutterSpeedValue);
 			if (str != null && str != "")
-				AddProperty (Beagle.Property.NewKeyword ("exif:ShutterSpeedValue", str));
+				AddProperty (Beagle.Property.NewUnsearched ("exif:ShutterSpeedValue", str));
 
 			str = exif.LookupFirstValue (ExifTag.ExposureTime);
 			if (str != null && str != "")
-				AddProperty (Beagle.Property.NewKeyword ("exif:ExposureTime", str));
+				AddProperty (Beagle.Property.NewUnsearched ("exif:ExposureTime", str));
 
 			str = exif.LookupFirstValue (ExifTag.FNumber);
 			if (str != null && str != "")
-				AddProperty (Beagle.Property.NewKeyword ("exif:FNumber", str));
+				AddProperty (Beagle.Property.NewUnsearched ("exif:FNumber", str));
 
 			str = exif.LookupFirstValue (ExifTag.ApertureValue);
 			if (str != null && str != "")
-				AddProperty (Beagle.Property.NewKeyword ("exif:ApertureValue", str));
+				AddProperty (Beagle.Property.NewUnsearched ("exif:ApertureValue", str));
 
 			str = exif.LookupFirstValue (ExifTag.FocalLength);
 			if (str != null && str != "")
-				AddProperty (Beagle.Property.NewKeyword ("exif:FocalLength", str));
+				AddProperty (Beagle.Property.NewUnsearched ("exif:FocalLength", str));
 
 			str = exif.LookupFirstValue (ExifTag.Flash);
 			if (str != null && str != "")
-				AddProperty (Beagle.Property.NewKeyword ("exif:Flash", str));
+				AddProperty (Beagle.Property.NewUnsearched ("exif:Flash", str));
 
 			str = exif.LookupFirstValue (ExifTag.Model);
 			if (str != null && str != "")
