@@ -210,12 +210,17 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 				try {
 					InitializeGMime ();
 				} catch (Exception e) {
-					Logger.Log.Warn ("Caught exception trying to initalize gmime:");
-					Logger.Log.Warn (e);
+					Logger.Log.Warn (e, "Caught exception trying to initalize gmime:");
 					return false;
 				}
 
 				this.mbox_fd = Mono.Unix.Native.Syscall.open (this.mbox_info.FullName, Mono.Unix.Native.OpenFlags.O_RDONLY);
+
+				if (this.mbox_fd < 0) {
+					Log.Error ("Unable to open {0}: {1}", this.mbox_info.FullName, Mono.Unix.Native.Stdlib.strerror (Mono.Unix.Native.Stdlib.GetLastError ()));
+					return false;
+				}
+
 				this.mbox_stream = new GMime.StreamFs (this.mbox_fd);
 				this.mbox_stream.Seek ((int) this.MboxLastOffset);
 				this.mbox_parser = new GMime.Parser (this.mbox_stream);
@@ -421,6 +426,8 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 		private string folder_cache_name;
 		private Hashtable mapping;
 		private ArrayList deleted_list;
+		private bool delete_mode;
+		private int delete_count;
 
 		public EvolutionMailIndexableGeneratorImap (EvolutionMailQueryable queryable, FileInfo summary_info) : base (queryable)
 		{
@@ -637,8 +644,7 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 					else
 						this.summary = Camel.Summary.LoadImap4Summary (this.summary_info.FullName);
 				} catch (Exception e) {
-					Logger.Log.Warn ("Unable to index {0}: {1}", this.folder_name,
-									 e.Message);
+					Logger.Log.Warn (e, "Unable to index {0}:", this.folder_name);
 					this.queryable.RemoveGeneratorProgress (this);
 					return false;
 				}
@@ -650,26 +656,20 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 			if (this.summary_enumerator.MoveNext ())
 				return true;
 
-			Logger.Log.Debug ("Queuing up {0} removals for deleted messages in ", this.deleted_list.Count, this.folder_name);
-			foreach (string uid in this.deleted_list) {
-				Uri uri = EvolutionMailQueryable.EmailUri (this.account_name, this.folder_name, uid);
+			this.delete_mode = true;
 
-				// FIXME: This is kind of a hack, but it's the only way
-				// with the IndexableGenerator to handle our removals.
-				Scheduler.Task task = this.queryable.NewRemoveTask (uri);
-				task.Priority = Scheduler.Priority.Immediate;
-				this.queryable.ThisScheduler.Add (task);
-			}
+			if (this.deleted_list.Count > 0)
+				return true;
 
 			string progress = "";
 			if (this.count > 0 && this.summary.header.count > 0) {
-				progress = String.Format (" ({0}/{1} {2:###.0}%)",
+				progress = String.Format ("({0}/{1} {2:###.0}%)",
 							  this.count,
 							  this.summary.header.count,
 							  100.0 * this.count / this.summary.header.count);
 			}
 
-			Logger.Log.Debug ("{0}: Finished indexing {1} messages{2}", this.folder_name, this.indexed_count, progress);
+			Logger.Log.Debug ("{0}: Finished indexing {1} messages {2}, {3} messages deleted", this.folder_name, this.indexed_count, progress, this.delete_count);
 
 			this.SaveCache ();
 			this.CrawlFinished ();
@@ -688,6 +688,21 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 		{
 			Indexable indexable = null;
 
+			// No more new messages to index, so start on the removals.
+			if (this.delete_mode) {
+				string uid = (string) this.deleted_list [0];
+				Uri uri = EvolutionMailQueryable.EmailUri (this.account_name, this.folder_name, uid);
+				
+				indexable = new Indexable (IndexableType.Remove, uri);
+
+				this.deleted_list.RemoveAt (0);
+				this.mapping.Remove (uid);
+
+				this.delete_count++;
+
+				return indexable;
+			}
+
 			Camel.MessageInfo mi = (Camel.MessageInfo) this.summary_enumerator.Current;
 
 			++this.count;
