@@ -72,17 +72,17 @@ class ExtractContentTool {
 
 		Filter filter;
 
-		if (! FilterFactory.FilterIndexable (indexable, out filter))
+		if (! FilterFactory.FilterIndexable (indexable, out filter)) {
 			Console.WriteLine ("No filter for {0}", indexable.MimeType);
-
-		if (filter != null) {
-			Console.WriteLine ("Filter: {0}", filter);
-			Console.WriteLine ("MimeType: {0}", filter.MimeType);
+			indexable.Cleanup ();
+			return;
 		}
 
+		Console.WriteLine ("Filter: {0}", filter);
+		Console.WriteLine ("MimeType: {0}", filter.MimeType);
 		Console.WriteLine ();
 
-		if (filter != null && filter.ChildIndexables != null && filter.ChildIndexables.Count > 0) {
+		if (filter.ChildIndexables != null && filter.ChildIndexables.Count > 0) {
 			Console.WriteLine ("Child indexables:");
 
 			foreach (Indexable i in filter.ChildIndexables)
@@ -124,6 +124,7 @@ class ExtractContentTool {
 				}
 				DisplayContent (line);
 			}
+			reader.Close ();
 
 			if (first)
 				Console.WriteLine ("(no content)");
@@ -142,6 +143,7 @@ class ExtractContentTool {
 				}
 				DisplayContent (line);
 			}
+			reader.Close ();
 
 			if (first)
 				Console.WriteLine ("(no hot content)");
@@ -149,13 +151,18 @@ class ExtractContentTool {
 				Console.WriteLine ();
 		}
 
-		if (show_children && filter != null && filter.ChildIndexables != null) {
+		Stream stream = indexable.GetBinaryStream ();
+		if (stream != null)
+			stream.Close ();
+
+		if (show_children && filter.ChildIndexables != null) {
 			foreach (Indexable i in filter.ChildIndexables) {
 				i.StoreStream ();
-				i.DeleteContent = true;
 				Display (i);
 			}
 		}
+		
+		indexable.Cleanup ();
 
 	}
 
@@ -241,6 +248,14 @@ class ExtractContentTool {
 		if (writer != null)
 			writer.Close ();
 
+		GLib.MainLoop main_loop = new GLib.MainLoop ();
+
+		if (Environment.GetEnvironmentVariable ("BEAGLE_TEST_MEMORY") != null) {
+			GC.Collect ();
+			GLib.Timeout.Add (1000, delegate() { main_loop.Quit (); return false; });
+			main_loop.Run ();
+		}
+
 		return 0;
 	}
 }
