@@ -536,7 +536,7 @@ namespace Beagle.Daemon {
 				if (HasError)
 					return false;				
 			} catch (Exception e) {
-				Logger.Log.Warn ("Unable to filter {0}: {1}", info.FullName, e.Message);
+				Log.Warn (e, "Unable to filter {0}:", info.FullName);
 				Cleanup (); // clean up temporary files on an exception
 				return false;
 			}
@@ -652,8 +652,7 @@ namespace Beagle.Daemon {
 			try {
 				pulled = PullFromArray (array, sb);
 			} catch (Exception ex) {
-				Logger.Log.Debug ("Caught exception while pulling text in filter '{0}'", Name);
-				Logger.Log.Debug (ex);
+				Logger.Log.Debug (ex, "Caught exception while pulling text in filter '{0}'", Name);
 			}
 
 			return pulled;
