@@ -148,7 +148,7 @@ namespace Beagle.Daemon.KMailQueryable {
 					RemoveMail (srcpath);
 				if (mbox_files.Contains (fullPath)) {
 					// check if this because of compaction, in which case need to delete previous mbox
-					if (srcpath.EndsWith ("." + subitem + ".compacted"))
+					if (srcpath != null && srcpath.EndsWith ("." + subitem + ".compacted"))
 						RemoveMbox (fullPath);
 					// FIXME need to ensure IndexMbox is scheduled *after* RemoveMbox finishes
 					// RemoveMbox creates a job with immediate priority while
@@ -159,7 +159,7 @@ namespace Beagle.Daemon.KMailQueryable {
 				return;
 			}
 
-			// Case: file is modified
+			// Case: file is modified i.e. there was no create event but closewrite event
 			// - possibly some mbox was changed
 			// FIXME kmail doesnt physically delete the deleted mails from mbox files unless compacted
 			// - which means one has to read the .index files to find deleted messages...
@@ -370,9 +370,9 @@ namespace Beagle.Daemon.KMailQueryable {
 			indexable.MimeType = "message/rfc822";
 			indexable.CacheContent = false;
 
-			indexable.AddProperty (Property.NewKeyword ("fixme:client", "kmail"));
-			indexable.AddProperty (Property.NewKeyword ("fixme:account", account_name));
-                        indexable.AddProperty (Property.NewKeyword ("fixme:folder", folder));
+			indexable.AddProperty (Property.NewUnsearched ("fixme:client", "kmail"));
+			indexable.AddProperty (Property.NewUnsearched ("fixme:account", account_name));
+                        indexable.AddProperty (Property.NewUnsearched ("fixme:folder", folder));
 			indexable.ContentUri = file_uri;
 
 			return indexable;
@@ -395,9 +395,9 @@ namespace Beagle.Daemon.KMailQueryable {
 			indexable.MimeType = "message/rfc822";
 			indexable.CacheContent = false;
 
-			indexable.AddProperty (Property.NewKeyword ("fixme:client", "kmail"));
-			indexable.AddProperty (Property.NewKeyword ("fixme:account", account_name));
-                        indexable.AddProperty (Property.NewKeyword ("fixme:folder", folder_name));
+			indexable.AddProperty (Property.NewUnsearched ("fixme:client", "kmail"));
+			indexable.AddProperty (Property.NewUnsearched ("fixme:account", account_name));
+                        indexable.AddProperty (Property.NewUnsearched ("fixme:folder", folder_name));
 
 			GMime.InternetAddressList addrs;
 
@@ -424,6 +424,12 @@ namespace Beagle.Daemon.KMailQueryable {
 
 			if (folder_name == Queryable.SentMailFolderName)
 				indexable.AddProperty (Property.NewFlag ("fixme:isSent"));
+			else {
+				string kmail_msg_sent = message.GetHeader ("X-KMail-Link-Type");
+				if (kmail_msg_sent == "reply")
+					indexable.AddProperty (Property.NewFlag ("fixme:isSent"));
+			}
+				
 // no need to store date again, use the issent flag to determine if the date is sentdate or not			
 #if false
 			if (folder_name == Queryable.SentMailFolderName)
@@ -467,7 +473,7 @@ namespace Beagle.Daemon.KMailQueryable {
 		 */
 		public bool IsMailDir (string dirPath)
 		{
-			if (! (dirPath.EndsWith("cur") || dirPath.EndsWith("new")))
+			if (dirPath == null || ! (dirPath.EndsWith("cur") || dirPath.EndsWith("new")))
 				return false;
 
 			string possibleMaildir = (Directory.GetParent (dirPath)).FullName;
