@@ -55,7 +55,8 @@ namespace Beagle.Daemon.LifereaQueryable {
 
 		// add versioning info
 		// v1: change property names to match DC element names
-		private const int INDEX_VERSION = 1;
+		// v2: remove dc:date, use Timestamp property.
+		private const int INDEX_VERSION = 2;
 		
 		public LifereaQueryable () : base ("LifereaIndex", INDEX_VERSION)
 		{
@@ -256,7 +257,7 @@ namespace Beagle.Daemon.LifereaQueryable {
 					}
 				} while (!reader.EOF && reader.NodeType == XmlNodeType.Element);
 			} catch (XmlException ex) {
-				Logger.Log.Debug ("Invalid feed file: " + ex.Message);
+				Logger.Log.Warn (ex, "Caught exception parsing feed file:");
 				is_valid_file = false;
 				reader.Close ();
 			}
@@ -327,7 +328,6 @@ namespace Beagle.Daemon.LifereaQueryable {
 					indexable.AddProperty (Property.New ("dc:creator", attrib.Value));
 				}
 			}
-			indexable.AddProperty (Property.NewDate ("dc:date", date));
 			indexable.AddProperty (Property.NewKeyword ("dc:identifier", current_item.Source));
 			indexable.AddProperty (Property.NewKeyword ("dc:source", feed_source));
 			indexable.AddProperty (Property.New ("dc:publisher", publisher));
