@@ -19,26 +19,27 @@ using Field = Lucene.Net.Documents.Field;
 using Similarity = Lucene.Net.Search.Similarity;
 using Directory = Lucene.Net.Store.Directory;
 using FSDirectory = Lucene.Net.Store.FSDirectory;
+using IndexInput = Lucene.Net.Store.IndexInput;
 using Lock = Lucene.Net.Store.Lock;
 namespace Lucene.Net.Index
 {
 	
-	/// <summary>IndexReader is an abstract class, providing an interface for accessing an
-	/// index.  Search of an index is done entirely through this abstract interface,
-	/// so that any subclass which implements it is searchable.
-	/// <p> Concrete subclasses of IndexReader are usually constructed with a call to
-	/// the static method {@link #open}.
-	/// <p> For efficiency, in this API documents are often referred to via
-	/// <i>document numbers</i>, non-negative integers which each name a unique
-	/// document in the index.  These document numbers are ephemeral--they may change
-	/// as documents are added to and deleted from an index.  Clients should thus not
-	/// rely on a given document having the same number between sessions.
-	/// </summary>
-	/// <author>  Doug Cutting
-	/// </author>
-	/// <version>  $Id: IndexReader.cs,v 1.2 2005/01/17 19:54:29 joeshaw Exp $
-	/// </version>
-	public abstract class IndexReader
+    /// <summary>IndexReader is an abstract class, providing an interface for accessing an
+    /// index.  Search of an index is done entirely through this abstract interface,
+    /// so that any subclass which implements it is searchable.
+    /// <p> Concrete subclasses of IndexReader are usually constructed with a call to
+    /// one of the static <code>open()</code> methods, e.g. {@link #Open(String)}.
+    /// <p> For efficiency, in this API documents are often referred to via
+    /// <i>document numbers</i>, non-negative integers which each name a unique
+    /// document in the index.  These document numbers are ephemeral--they may change
+    /// as documents are added to and deleted from an index.  Clients should thus not
+    /// rely on a given document having the same number between sessions.
+    /// </summary>
+    /// <author>  Doug Cutting
+    /// </author>
+    /// <version>  $Id: IndexReader.cs,v 1.3 2005/10/06 19:29:55 dsd Exp $
+    /// </version>
+    public abstract class IndexReader
 	{
 		private class AnonymousClassWith : Lock.With
 		{
@@ -60,16 +61,13 @@ namespace Lucene.Net.Index
 				if (infos.Count == 1)
 				{
 					// index is optimized
-					return new SegmentReader(infos, infos.Info(0), closeDirectory);
+                    return SegmentReader.Get(infos, infos.Info(0), closeDirectory);
 				}
-				else
-				{
-					IndexReader[] readers = new IndexReader[infos.Count];
-					for (int i = 0; i < infos.Count; i++)
-						readers[i] = new SegmentReader(infos.Info(i));
-					return new MultiReader(directory, infos, closeDirectory, readers);
-				}
-			}
+                IndexReader[] readers = new IndexReader[infos.Count];
+                for (int i = 0; i < infos.Count; i++)
+                    readers[i] = SegmentReader.Get(infos.Info(i));
+                return new MultiReader(directory, infos, closeDirectory, readers);
+            }
 		}
 		private class AnonymousClassWith1 : Lock.With
 		{
@@ -98,7 +96,41 @@ namespace Lucene.Net.Index
 			}
 		}
 		
-		/// <summary> Constructor used if IndexReader is not owner of its directory. 
+        public sealed class FieldOption
+        {
+            private System.String option;
+            internal FieldOption()
+            {
+            }
+            internal FieldOption(System.String option)
+            {
+                this.option = option;
+            }
+            public override System.String ToString()
+            {
+                return this.option;
+            }
+            // all fields
+            public static readonly FieldOption ALL = new FieldOption("ALL");
+            // all indexed fields
+            public static readonly FieldOption INDEXED = new FieldOption("INDEXED");
+            // all fields which are not indexed
+            public static readonly FieldOption UNINDEXED = new FieldOption("UNINDEXED");
+            // all fields which are indexed with termvectors enables
+            public static readonly FieldOption INDEXED_WITH_TERMVECTOR = new FieldOption("INDEXED_WITH_TERMVECTOR");
+            // all fields which are indexed but don't have termvectors enabled
+            public static readonly FieldOption INDEXED_NO_TERMVECTOR = new FieldOption("INDEXED_NO_TERMVECTOR");
+            // all fields where termvectors are enabled. Please note that only standard termvector fields are returned
+            public static readonly FieldOption TERMVECTOR = new FieldOption("TERMVECTOR");
+            // all field with termvectors wiht positions enabled
+            public static readonly FieldOption TERMVECTOR_WITH_POSITION = new FieldOption("TERMVECTOR_WITH_POSITION");
+            // all fields where termvectors with offset position are set
+            public static readonly FieldOption TERMVECTOR_WITH_OFFSET = new FieldOption("TERMVECTOR_WITH_OFFSET");
+            // all fields where termvectors with offset and position values set
+            public static readonly FieldOption TERMVECTOR_WITH_POSITION_OFFSET = new FieldOption("TERMVECTOR_WITH_POSITION_OFFSET");
+        }
+		
+        /// <summary> Constructor used if IndexReader is not owner of its directory. 
 		/// This is used for IndexReaders that are used within other IndexReaders that take care or locking directories.
 		/// 
 		/// </summary>
@@ -107,12 +139,6 @@ namespace Lucene.Net.Index
 		protected internal IndexReader(Directory directory)
 		{
 			this.directory = directory;
-			segmentInfos = null;
-			directoryOwner = false;
-			closeDirectory = false;
-			stale = false;
-			hasChanges = false;
-			writeLock = null;
 		}
 		
 		/// <summary> Constructor used if IndexReader is owner of its directory.
@@ -127,24 +153,26 @@ namespace Lucene.Net.Index
 		/// </param>
 		internal IndexReader(Directory directory, SegmentInfos segmentInfos, bool closeDirectory)
 		{
-			this.directory = directory;
-			this.segmentInfos = segmentInfos;
-			directoryOwner = true;
-			this.closeDirectory = closeDirectory;
-			stale = false;
-			hasChanges = false;
-			writeLock = null;
+			Init(directory, segmentInfos, closeDirectory, true);
 		}
 		
-		private Directory directory;
+        internal virtual void  Init(Directory directory, SegmentInfos segmentInfos, bool closeDirectory, bool directoryOwner)
+        {
+            this.directory = directory;
+            this.segmentInfos = segmentInfos;
+            this.directoryOwner = directoryOwner;
+            this.closeDirectory = closeDirectory;
+        }
 		
+        private Directory directory;		
 		private bool directoryOwner;
+        private bool closeDirectory;
+        
 		private SegmentInfos segmentInfos;
 		private Lock writeLock;
 		private bool stale;
 		private bool hasChanges;
 		
-		private bool closeDirectory;
 		
 		/// <summary>Returns an IndexReader reading the index in an FSDirectory in the named
 		/// path. 
@@ -173,7 +201,7 @@ namespace Lucene.Net.Index
 			lock (directory)
 			{
 				// in- & inter-process sync
-				return (IndexReader) new AnonymousClassWith(directory, closeDirectory, directory.MakeLock(IndexWriter.COMMIT_LOCK_NAME), IndexWriter.COMMIT_LOCK_TIMEOUT).run();
+				return (IndexReader) new AnonymousClassWith(directory, closeDirectory, directory.MakeLock(IndexWriter.COMMIT_LOCK_NAME), IndexWriter.COMMIT_LOCK_TIMEOUT).Run();
 			}
 		}
 		
@@ -279,26 +307,43 @@ namespace Lucene.Net.Index
 			return SegmentInfos.ReadCurrentVersion(directory);
 		}
 		
-		/// <summary>Return an array of term frequency vectors for the specified document.
-		/// The array contains a vector for each vectorized Field in the document.
-		/// Each vector contains terms and frequencies for all terms
-		/// in a given vectorized Field.
-		/// If no such fields existed, the method returns null.
-		/// 
-		/// </summary>
-		/// <seealso cref="Field#IsTermVectorStored()">
-		/// </seealso>
-		abstract public TermFreqVector[] GetTermFreqVectors(int docNumber);
+        /// <summary>  Return an array of term frequency vectors for the specified document.
+        /// The array contains a vector for each vectorized field in the document.
+        /// Each vector contains terms and frequencies for all terms in a given vectorized field.
+        /// If no such fields existed, the method returns null. The term vectors that are
+        /// returned my either be of type TermFreqVector or of type TermPositionsVector if
+        /// positions or offsets have been stored.
+        /// 
+        /// </summary>
+        /// <param name="docNumber">document for which term frequency vectors are returned
+        /// </param>
+        /// <returns> array of term frequency vectors. May be null if no term vectors have been
+        /// stored for the specified document.
+        /// </returns>
+        /// <throws>  IOException if index cannot be accessed </throws>
+        /// <seealso cref="Lucene.Net.document.Field.TermVector">
+        /// </seealso>
+        abstract public TermFreqVector[] GetTermFreqVectors(int docNumber);
+        
 		
-		/// <summary>Return a term frequency vector for the specified document and Field. The
-		/// vector returned contains terms and frequencies for those terms in
-		/// the specified Field of this document, if the Field had storeTermVector
-		/// flag set.  If the flag was not set, the method returns null.
-		/// 
-		/// </summary>
-		/// <seealso cref="Field#IsTermVectorStored()">
-		/// </seealso>
-		abstract public TermFreqVector GetTermFreqVector(int docNumber, System.String field);
+        /// <summary>  Return a term frequency vector for the specified document and field. The
+        /// returned vector contains terms and frequencies for the terms in
+        /// the specified field of this document, if the field had the storeTermVector
+        /// flag set. If termvectors had been stored with positions or offsets, a 
+        /// TermPositionsVector is returned.
+        /// 
+        /// </summary>
+        /// <param name="docNumber">document for which the term frequency vector is returned
+        /// </param>
+        /// <param name="field">field for which the term frequency vector is returned.
+        /// </param>
+        /// <returns> term frequency vector May be null if field does not exist in the specified
+        /// document or term vector was not stored.
+        /// </returns>
+        /// <throws>  IOException if index cannot be accessed </throws>
+        /// <seealso cref="Lucene.Net.document.Field.TermVector">
+        /// </seealso>
+        abstract public TermFreqVector GetTermFreqVector(int docNumber, System.String field);
 		
 		/// <summary> Returns <code>true</code> if an index exists at the specified directory.
 		/// If the directory does not exist or if there is no index in it.
@@ -483,7 +528,7 @@ namespace Lucene.Net.Index
 		/// <summary>Returns an unpositioned {@link TermPositions} enumerator. </summary>
 		public abstract TermPositions TermPositions();
 		
-		/// <summary> Trys to acquire the WriteLock on this directory.
+		/// <summary> Tries to acquire the WriteLock on this directory.
 		/// this method is only valid if this IndexReader is directory owner.
 		/// 
 		/// </summary>
@@ -543,7 +588,9 @@ namespace Lucene.Net.Index
 		/// the document.  Then to delete such a document, one merely constructs a
 		/// term with the appropriate Field and the unique ID string as its text and
 		/// passes it to this method.  Returns the number of documents deleted.
-		/// </summary>
+        /// See {@link #Delete(int)} for information about when this deletion will 
+        /// become effective.
+        /// </summary>
 		public int Delete(Term term)
 		{
 			TermDocs docs = TermDocs(term);
@@ -595,7 +642,7 @@ namespace Lucene.Net.Index
 						lock (directory)
 						{
 							// in- & inter-process sync
-							new AnonymousClassWith1(this, directory.MakeLock(IndexWriter.COMMIT_LOCK_NAME), IndexWriter.COMMIT_LOCK_TIMEOUT).run();
+							new AnonymousClassWith1(this, directory.MakeLock(IndexWriter.COMMIT_LOCK_NAME), IndexWriter.COMMIT_LOCK_TIMEOUT).Run();
 						}
 						if (writeLock != null)
 						{
@@ -642,35 +689,107 @@ namespace Lucene.Net.Index
 			}
 		}
 		
-		/// <summary> Returns a list of all unique Field names that exist in the index pointed
-		/// to by this IndexReader.
-		/// </summary>
-		/// <returns> Collection of Strings indicating the names of the fields
-		/// </returns>
-		/// <throws>  IOException if there is a problem with accessing the index </throws>
-		public abstract System.Collections.ICollection GetFieldNames();
+        /// <summary> Returns a list of all unique field names that exist in the index pointed
+        /// to by this IndexReader.
+        /// </summary>
+        /// <returns> Collection of Strings indicating the names of the fields
+        /// </returns>
+        /// <throws>  IOException if there is a problem with accessing the index </throws>
+        /// <summary> 
+        /// </summary>
+        /// <deprecated>  Replaced by {@link #GetFieldNames(IndexReader.FieldOption)}
+        /// </deprecated>
+        public abstract System.Collections.ICollection GetFieldNames();
 		
 		/// <summary> Returns a list of all unique Field names that exist in the index pointed
 		/// to by this IndexReader.  The boolean argument specifies whether the fields
-		/// returned are indexed or not.
-		/// </summary>
-		/// <param name="indexed"><code>true</code> if only indexed fields should be returned;
-		/// <code>false</code> if only unindexed fields should be returned.
-		/// </param>
-		/// <returns> Collection of Strings indicating the names of the fields
-		/// </returns>
-		/// <throws>  IOException if there is a problem with accessing the index </throws>
-		public abstract System.Collections.ICollection GetFieldNames(bool indexed);
+        /// returned are indexed or not.
+        /// </summary>
+        /// <param name="indexed"><code>true</code> if only indexed fields should be returned;
+        /// <code>false</code> if only unindexed fields should be returned.
+        /// </param>
+        /// <returns> Collection of Strings indicating the names of the fields
+        /// </returns>
+        /// <throws>  IOException if there is a problem with accessing the index </throws>
+        /// <summary> 
+        /// </summary>
+        /// <deprecated>  Replaced by {@link #GetFieldNames(IndexReader.FieldOption)}
+        /// </deprecated>
+        public abstract System.Collections.ICollection GetFieldNames(bool indexed);
 		
-		/// <summary> </summary>
-		/// <param name="storedTermVector">if true, returns only Indexed fields that have term vector info, 
-		/// else only indexed fields without term vector info 
-		/// </param>
-		/// <returns> Collection of Strings indicating the names of the fields
-		/// </returns>
-		public abstract System.Collections.ICollection GetIndexedFieldNames(bool storedTermVector);
+        /// <summary> </summary>
+        /// <param name="storedTermVector">if true, returns only Indexed fields that have term vector info, 
+        /// else only indexed fields without term vector info 
+        /// </param>
+        /// <returns> Collection of Strings indicating the names of the fields
+        /// 
+        /// </returns>
+        /// <deprecated>  Replaced by {@link #GetFieldNames(IndexReader.FieldOption)}
+        /// </deprecated>
+        public virtual System.Collections.ICollection GetIndexedFieldNames(bool storedTermVector)
+        {
+            if (storedTermVector)
+            {
+                System.Collections.Hashtable fieldSet = new System.Collections.Hashtable();
+                foreach (object item in GetIndexedFieldNames(Field.TermVector.YES))
+                {
+                    if (fieldSet.ContainsKey(item) == false)
+                    {
+                        fieldSet.Add(item, item);
+                    }
+                }
+                foreach (object item in GetIndexedFieldNames(Field.TermVector.WITH_POSITIONS))
+                {
+                    if (fieldSet.ContainsKey(item) == false)
+                    {
+                        fieldSet.Add(item, item);
+                    }
+                }
+                foreach (object item in GetIndexedFieldNames(Field.TermVector.WITH_OFFSETS))
+                {
+                    if (fieldSet.ContainsKey(item) == false)
+                    {
+                        fieldSet.Add(item, item);
+                    }
+                }
+                foreach (object item in GetIndexedFieldNames(Field.TermVector.WITH_POSITIONS_OFFSETS))
+                {
+                    if (fieldSet.ContainsKey(item) == false)
+                    {
+                        fieldSet.Add(item, item);
+                    }
+                }
+                return fieldSet;
+            }
+            else
+                return GetIndexedFieldNames(Field.TermVector.NO);
+        }
 		
-		/// <summary> Returns <code>true</code> iff the index in the named directory is
+        /// <summary> Get a list of unique field names that exist in this index, are indexed, and have
+        /// the specified term vector information.
+        /// 
+        /// </summary>
+        /// <param name="tvSpec">specifies which term vector information should be available for the fields
+        /// </param>
+        /// <returns> Collection of Strings indicating the names of the fields
+        /// 
+        /// </returns>
+        /// <deprecated>  Replaced by {@link #GetFieldNames(IndexReader.FieldOption)}
+        /// </deprecated>
+        public abstract System.Collections.ICollection GetIndexedFieldNames(Field.TermVector tvSpec);
+		
+        /// <summary> Get a list of unique field names that exist in this index and have the specified
+        /// field option information.
+        /// </summary>
+        /// <param name="fldOption">specifies which field option should be available for the returned fields
+        /// </param>
+        /// <returns> Collection of Strings indicating the names of the fields.
+        /// </returns>
+        /// <seealso cref="IndexReader.FieldOption">
+        /// </seealso>
+        public abstract System.Collections.ICollection GetFieldNames(FieldOption fldOption);
+		
+        /// <summary> Returns <code>true</code> iff the index in the named directory is
 		/// currently locked.
 		/// </summary>
 		/// <param name="directory">the directory to check for a lock
@@ -706,5 +825,107 @@ namespace Lucene.Net.Index
 			directory.MakeLock(IndexWriter.WRITE_LOCK_NAME).Release();
 			directory.MakeLock(IndexWriter.COMMIT_LOCK_NAME).Release();
 		}
-	}
+		
+        /// <summary> Prints the filename and size of each file within a given compound file.
+        /// Add the -extract flag to extract files to the current working directory.
+        /// In order to make the extracted version of the index work, you have to copy
+        /// the segments file from the compound index into the directory where the extracted files are stored.
+        /// </summary>
+        /// <param name="">args
+        /// </param>
+        [STAThread]
+        public static void  Main(System.String[] args)
+        {
+            System.String dirname = null, filename = null;
+            bool extract = false;
+			
+            for (int i = 0; i < args.Length; ++i)
+            {
+                if (args[i].Equals("-extract"))
+                {
+                    extract = true;
+                }
+                else if (dirname == null)
+                {
+                    dirname = args[i];
+                }
+                else if (filename == null)
+                {
+                    filename = args[i];
+                }
+            }
+			
+            if (dirname == null || filename == null)
+            {
+                System.Console.Out.WriteLine("Usage: Lucene.Net.index.IndexReader [-extract] <directory> <cfsfile>");
+                return ;
+            }
+			
+            Directory dir = null;
+            CompoundFileReader cfr = null;
+			
+            try
+            {
+                dir = FSDirectory.GetDirectory(dirname, false);
+				
+                cfr = new CompoundFileReader(dir, filename);
+				
+                System.String[] files = cfr.List();
+                System.Array.Sort(files); // sort the array of filename so that the output is more readable
+				
+                for (int i = 0; i < files.Length; ++i)
+                {
+                    long len = cfr.FileLength(files[i]);
+					
+                    if (extract)
+                    {
+                        System.Console.Out.WriteLine("extract " + files[i] + " with " + len + " bytes to local directory...");
+                        IndexInput ii = cfr.OpenInput(files[i]);
+						
+                        System.IO.FileStream f = new System.IO.FileStream(files[i], System.IO.FileMode.Create);
+						
+                        // read and write with a small buffer, which is more effectiv than reading byte by byte
+                        byte[] buffer = new byte[1024];
+                        int chunk = buffer.Length;
+                        while (len > 0)
+                        {
+                            int bufLen = (int) System.Math.Min(chunk, len);
+                            ii.ReadBytes(buffer, 0, bufLen);
+
+                            byte[] byteArray = new byte[buffer.Length];
+                            for (int index=0; index < buffer.Length; index++)
+                                byteArray[index] = (byte) buffer[index];
+
+                            f.Write(byteArray, 0, bufLen);
+
+                            len -= bufLen;
+                        }
+						
+                        f.Close();
+                        ii.Close();
+                    }
+                    else
+                        System.Console.Out.WriteLine(files[i] + ": " + len + " bytes");
+                }
+            }
+            catch (System.IO.IOException ioe)
+            {
+                System.Console.Error.WriteLine(ioe.StackTrace);
+            }
+            finally
+            {
+                try
+                {
+                    if (dir != null)
+                        dir.Close();
+                    if (cfr != null)
+                        cfr.Close();
+                }
+                catch (System.IO.IOException ioe)
+                {
+                    System.Console.Error.WriteLine(ioe.StackTrace);
+                }
+            }
+        }
+    }
 }
\ No newline at end of file
