@@ -28,7 +28,6 @@
 #ifndef __BEAGLE_H
 #define __BEAGLE_H
 
-#include <beagle/beagle-cancelled-response.h>
 #include <beagle/beagle-client.h>
 #include <beagle/beagle-daemon-information-request.h>
 #include <beagle/beagle-daemon-information-response.h>
@@ -40,6 +39,7 @@
 #include <beagle/beagle-indexable.h>
 #include <beagle/beagle-indexing-service-request.h>
 #include <beagle/beagle-property.h>
+#include <beagle/beagle-scheduler-information.h>
 #include <beagle/beagle-query.h>
 #include <beagle/beagle-query-part.h>
 #include <beagle/beagle-query-part-date.h>
@@ -47,6 +47,8 @@
 #include <beagle/beagle-query-part-or.h>
 #include <beagle/beagle-query-part-property.h>
 #include <beagle/beagle-query-part-text.h>
+#include <beagle/beagle-query-part-wildcard.h>
+#include <beagle/beagle-queryable-status.h>
 #include <beagle/beagle-request.h>
 #include <beagle/beagle-response.h>
 #include <beagle/beagle-search-term-response.h>
