@@ -218,7 +218,7 @@ namespace Search {
 			}
 
 			if (IconEnabled) {
-				tray = new TrayIcon ();
+				tray = new Search.Tray.TrayIcon ();
 				tray.Clicked += OnTrayActivated;
 				tray.Search += OnTraySearch;
 
@@ -418,7 +418,8 @@ namespace Search {
 		private void OnTrayActivated (object o, EventArgs args)
 		{
 			if (! Visible) {
-				ShowAll ();
+				base.ShowAll ();
+				base.Present ();
 				entry.GrabFocus ();
 			} else {
 				base.Hide ();
