@@ -28,14 +28,25 @@ namespace Search.Tiles {
 			Group = TileGroup.Conversations;
 
 			Subject.LabelProp = Catalog.GetString ("IM Conversation");
-			From.LabelProp = "<b>" + hit.GetFirstProperty ("fixme:speakingto") + "</b>";
+
+			string alias = hit.GetFirstProperty ("fixme:speakingto_alias");
+			string name = hit.GetFirstProperty ("fixme:speakingto");
+
+			if (alias != null && alias != "")
+				From.LabelProp = "<b>" + alias + "</b>";
+			else if (name != null && name != "")
+				From.LabelProp = "<b>" + name + "</b>";
+			else
+				From.LabelProp = "(unknown)";
 
 			try {
 				Timestamp = Utils.ParseTimestamp (hit.GetFirstProperty ("fixme:starttime"));
 				Date.LabelProp = Utils.NiceShortDate (Timestamp);
 			} catch {}
+
 		}
 
+
 		private Hashtable IconsForSize (int size)
 		{
 			Hashtable icons = new Hashtable ();
@@ -78,11 +89,11 @@ namespace Search.Tiles {
 			DetailsPane details = new DetailsPane ();
 
 			details.Icon.Pixbuf = LoadBuddyIcon ();			
-			details.AddLabelPair (Catalog.GetString ("Name:"), FromLabel.Text, 0, 1);
-			details.AddLabelPair (Catalog.GetString ("Date Received:"), Utils.NiceLongDate (Timestamp), 1, 1);
+			details.AddLabelPair (Catalog.GetString ("Name:"), FromLabel.Text);
+			details.AddLabelPair (Catalog.GetString ("Date Received:"), Utils.NiceLongDate (Timestamp));
+			details.AddSnippet ();
 
 			GotSnippet += SetSubject;
-			details.AddSnippet (2, 1);
 
 			return details;
 		}
