@@ -22,13 +22,11 @@ namespace Search.Tiles {
 			if (! base.Validate (hit))
 				return false;
 
-			string str = hit ["parent:fixme:hasAttachments"];
-
+			string str = hit.GetFirstProperty ("parent:fixme:hasAttachments");
 			if (hit.ParentUri == null || str == null || str == "false")
 				return false;
 
-			str = hit ["fixme:attachment_title"];
-
+			str = hit.GetFirstProperty ("fixme:attachment_title");
 			if (str == null || str == "")
 				return false;
 
@@ -42,6 +40,7 @@ namespace Search.Tiles {
 
 		public MailAttachment (Beagle.Hit hit, Beagle.Query query) : base (hit, query)
 		{
+			Group = TileGroup.Documents;
 			Title = Hit ["fixme:attachment_title"];
 			Description = Catalog.GetString ("Mail attachment");
 		}
@@ -68,25 +67,23 @@ namespace Search.Tiles {
 
 		public override void Open ()
 		{
-			if (GetHitProperty (Hit, "fixme:client") != "evolution") {
+			SafeProcess p;
+			
+			if (Hit.ParentUri != null)
+				p = MailMessage.GetClientProcess (GetHitProperty (Hit, "fixme:client"), Hit.ParentUri.ToString ());
+			else
+				p = MailMessage.GetClientProcess (GetHitProperty (Hit, "fixme:client"), Hit.Uri.ToString ());
+			if (p == null) {
 				OpenFromMime (Hit);
 				return;
 			}
 
-			SafeProcess p = new SafeProcess ();
-			p.Arguments = new string [2];
-			p.Arguments [0] = "evolution";
-
-			if (Hit.ParentUriAsString != null)
-				p.Arguments [1] = Hit.ParentUriAsString;
-			else
-				p.Arguments [1] = Hit.UriAsString;
-
 			try {
 				p.Start ();
 			} catch (SafeProcessException e) {
 				Console.WriteLine ("Unable to run {0}: {1}", p.Arguments [0], e.Message);
 			}
-		}	
+		}
+		
 	}
 }
