@@ -1,5 +1,5 @@
 using System;
-using Mono.Posix;
+using Mono.Unix;
 
 namespace Search.Tiles {
 
@@ -22,14 +22,8 @@ namespace Search.Tiles {
 		{
 			Group = TileGroup.Video;
 
-			Icon = WidgetFu.LoadThumbnailIcon (Hit.Uri, 32);
-
-			if (Icon == null)
-				Icon = WidgetFu.LoadMimeIcon (Hit ["beagle:MimeType"], 32);
-
 			// FIXME: We need filters for video in Beagle.
 			// They should land soon when entagged-sharp gets video support.
-			Title = Hit.GetFirstProperty ("beagle:ExactFilename");
 			Description = Catalog.GetString ("Unknown duration"); // FIXME: Duration from filters
 		}
 	}
