@@ -31,8 +31,10 @@ using System.Globalization;
 using System.Reflection;
 using System.Threading;
 using System.Text;
+using System.Text.RegularExpressions;
+using System.Runtime.InteropServices;
 
-using Gtk;
+using GLib;
 
 using Beagle;
 using Beagle.Util;
@@ -40,21 +42,22 @@ using Beagle.Daemon;
 
 class QueryTool {
 
-	static int count = 0;
-	static Query query = null;
-	static DateTime queryStartTime;
-	static DateTime lastQueryTime = DateTime.Now;
+	private static int count = 0;
+	private static Query query = null;
+	private static DateTime queryStartTime;
+	private static DateTime lastQueryTime = DateTime.Now;
 
+	private static MainLoop main_loop = null;
 	// CLI args
-	static bool keep_running = false;
-	static bool verbose = false;
-	static bool display_hits = true;
-	static bool flood = false;
-	static bool listener = false;
-	static DateTime start_date = DateTime.MinValue;
-	static DateTime end_date = DateTime.MinValue;
+	private static bool keep_running = false;
+	private static bool verbose = false;
+	private static bool display_hits = true;
+	private static bool flood = false;
+	private static bool listener = false;
+	private static DateTime start_date = DateTime.MinValue;
+	private static DateTime end_date = DateTime.MinValue;
 
-	static void OnHitsAdded (HitsAddedResponse response)
+	private static void OnHitsAdded (HitsAddedResponse response)
 	{
 		lastQueryTime = DateTime.Now;
 
@@ -87,7 +90,7 @@ class QueryTool {
 					Console.WriteLine (" Time: {0}", hit.Timestamp.ToLocalTime ());
 				
 				foreach (Property prop in hit.Properties)
-					Console.WriteLine ("    {0} = {1}", prop.Key, prop.Value);
+					Console.WriteLine ("    {0} = '{1}'", prop.Key, prop.Value);
 				
 				Console.WriteLine ();
 			}
@@ -96,7 +99,7 @@ class QueryTool {
 		}
 	}
 
-	static void OnHitsSubtracted (HitsSubtractedResponse response)
+	private static void OnHitsSubtracted (HitsSubtractedResponse response)
 	{
 		lastQueryTime = DateTime.Now;
 
@@ -111,7 +114,7 @@ class QueryTool {
 		}
 	}
 
-	static void OnFinished (FinishedResponse response)
+	private static void OnFinished (FinishedResponse response)
 	{
 		if (verbose) {
 			Console.WriteLine ("Elapsed time: {0:0.000}s",
@@ -122,7 +125,7 @@ class QueryTool {
 		if (flood)
 			SendQuery ();
 		else
-			Gtk.Application.Quit ();
+			main_loop.Quit ();
 	}
 
 	public static void PrintUsageAndExit () 
@@ -162,7 +165,7 @@ class QueryTool {
 		System.Environment.Exit (0);
 	}
 
-	static void ReadBackendMappings ()
+	private static void ReadBackendMappings ()
 	{
 		ArrayList assemblies = ReflectionFu.ScanEnvironmentForAssemblies ("BEAGLE_BACKEND_PATH", PathFinder.BackendDir);
 
@@ -202,16 +205,16 @@ class QueryTool {
 		}
 	}
 
-	static void OnClosed ()
+	private static void OnClosed ()
 	{
 		if (flood)
 			SendQuery ();
 		else
-			Gtk.Application.Quit ();
+			main_loop.Quit ();
 	}
 
-	static int query_counter = 0;
-	static void SendQuery ()
+	private static int query_counter = 0;
+	private static void SendQuery ()
 	{
 		++query_counter;
 		if (flood) {
@@ -230,9 +233,15 @@ class QueryTool {
 		}
 	}
 	
-	static void Main (string[] args) 
+	[DllImport("libgobject-2.0.so.0")]
+	static extern void g_type_init ();
+
+	public static void Main (string[] args) 
 	{
-		Gtk.Application.InitCheck ("beagle-query", ref args);
+		// Initialize GObject type system
+		g_type_init ();
+
+		main_loop = new MainLoop ();
 
 		if (args.Length == 0 || Array.IndexOf (args, "--help") > -1 || Array.IndexOf (args, "--usage") > -1)
 			PrintUsageAndExit ();
@@ -329,12 +338,23 @@ class QueryTool {
 				break;
 
 			default:
+				
+				// We have to do some nastiness here to deal with shell quoting.
+				// See beagled/QueryStringParser.cs for an idea of how this works.
+				string Pattern = "(?<pm>[+-]?) (?<key>\\w+:)? (?<expr>.*)";
+				Regex r = new Regex (Pattern, RegexOptions.IgnorePatternWhitespace);
+				Match m = r.Match (args [i]);
+				
+				string quoted_query = m.Groups ["pm"].ToString () +
+					m.Groups ["key"].ToString () +
+					"\"" + m.Groups ["expr"].ToString () + "\"";
+				
 				if (query_str.Length > 0)
 					query_str.Append (' ');
-				query_str.Append ('"');
-				query_str.Append (args [i]);
-				query_str.Append ('"');
+				query_str.Append (quoted_query);
+				
 				break;
+				
 			}
 
 			++i;
@@ -373,7 +393,7 @@ class QueryTool {
 
 		SendQuery ();
 
-		Gtk.Application.Run ();
+		main_loop.Run ();
 	}
 
 
