@@ -31,7 +31,6 @@ using System.Threading;
 
 using Gtk;
 using Gdk;
-using GConf;
 using Glade;
 using Mono.Unix;
 
@@ -49,7 +48,11 @@ public class SettingsDialog
 	////////////////////////////////////////////////////////////////
 	// Widgets
 
+	[Widget] VBox administration_frame;
+	[Widget] CheckButton allow_root_toggle;
+
 	[Widget] CheckButton autostart_toggle;
+	[Widget] CheckButton battery_toggle;
 
 	[Widget] CheckButton press_ctrl_toggle;
  	[Widget] CheckButton press_alt_toggle;
@@ -106,6 +109,8 @@ public class SettingsDialog
 		Glade.XML glade = new Glade.XML (null, "settings.glade", "settings_dialog", "beagle");
 		glade.Autoconnect (this);
 
+		administration_frame.Visible = (Environment.UserName == "root");
+
 #if false
 		display_view = new DisplayView ();
 		display_view.Selection.Changed += new EventHandler (OnDisplaySelected);
@@ -157,7 +162,9 @@ public class SettingsDialog
 
 	private void LoadConfiguration ()
 	{	
+		allow_root_toggle.Active = Conf.Daemon.AllowRoot;
 		autostart_toggle.Active = Conf.Searching.Autostart;
+		battery_toggle.Active = Conf.Indexing.IndexOnBattery;
 
 		KeyBinding show_binding = Conf.Searching.ShowSearchWindowBinding;
 		press_ctrl_toggle.Active = show_binding.Ctrl;
@@ -188,7 +195,9 @@ public class SettingsDialog
 
 	private void SaveConfiguration ()
 	{
+		Conf.Daemon.AllowRoot = allow_root_toggle.Active;
 		Conf.Searching.Autostart = autostart_toggle.Active;
+		Conf.Indexing.IndexOnBattery = battery_toggle.Active;
 		
 		Conf.Searching.ShowSearchWindowBinding = new KeyBinding (show_search_window_entry.Text, 
 									 press_ctrl_toggle.Active, 
@@ -233,7 +242,7 @@ public class SettingsDialog
 	{
 		switch (args.ResponseId) {
 		case ResponseType.Help:
-			Gnome.Url.Show ("http://www.beagle-project.org/Configuration_Help");
+			Gnome.Url.Show ("http://beagle-project.org/Configuring");
 			break;
 		case ResponseType.Ok:
 			SaveConfiguration ();
@@ -675,13 +684,13 @@ public class SettingsDialog
 
 			switch (exclude_item.Type) {
 			case ExcludeType.Path:
-				((CellRendererText)renderer).Text = Catalog.GetString ("Path");
+				((CellRendererText)renderer).Text = Catalog.GetString ("Path:");
 				break;
 			case ExcludeType.Pattern:
-				((CellRendererText)renderer).Text = Catalog.GetString ("Pattern");
+				((CellRendererText)renderer).Text = Catalog.GetString ("Pattern:");
 				break;
 			case ExcludeType.MailFolder:
-				((CellRendererText)renderer).Text = Catalog.GetString ("Mail Folder");
+				((CellRendererText)renderer).Text = Catalog.GetString ("Mail folder:");
 				break;
 			}
 		}
@@ -1055,17 +1064,17 @@ public class SettingsDialog
 			switch (Type) {
 			case ExcludeType.Path:
 				browse_button.Sensitive = true;
-				value_name_label.Text = Catalog.GetString ("Path");
+				value_name_label.TextWithMnemonic = Catalog.GetString ("P_ath:");
 				value_entry.IsEditable = true;
 				break;
 			case ExcludeType.MailFolder:
 				browse_button.Sensitive = true;
-				value_name_label.Text = Catalog.GetString ("Mail Folder");
+				value_name_label.TextWithMnemonic = Catalog.GetString ("M_ail folder:");
 				value_entry.IsEditable = false;
 				break;
 			case ExcludeType.Pattern:
 				browse_button.Sensitive = false;
-				value_name_label.Text = Catalog.GetString ("Pattern");
+				value_name_label.TextWithMnemonic = Catalog.GetString ("P_attern:");
 				value_entry.IsEditable = true;
 				break;
 			}
